Learn R Programming

RKelly (version 1.0)

chance_to_draw_n_games: Calculates the chance to draw out of n matches

Description

Calculates the chance to draw out of n matches

Usage

chance_to_draw_n_games(p, n)

Arguments

p

probability of first (or second) player winning match

n

number of matches

Value

The decimal chance for a draw

Examples

Run this code
# NOT RUN {
chance_to_draw_n_games(0.4, 4) # Draw chance if one player has p=0.4 in four matches
# }

Run the code above in your browser using DataLab