powered by
The Kelly criterion
kelly_criterion(p, alpha_w, alpha_l)
The objective probability of the event
The return multiplier in case of the event happening
The return multiplier in case of the event not happening
The Kelly optimised fraction of the bankroll that should be bet
Thorp, Edward O. (1997; revised 1998). The Kelly Criterion in Blackjack, Sports Betting, and the Stock Market. http://www.eecs.harvard.edu/cs286r/courses/fall12/papers/Thorpe_KellyCriterion2007.pdf
# NOT RUN { kelly_criterion(0.5,1,1) # }
Run the code above in your browser using DataLab